multidim.models.CDER
====================

.. currentmodule:: multidim.models

.. autoclass:: CDER

   

      .. autosummary::
         :toctree:
      
         CDER.build_gaussian
         CDER.evaluate
         CDER.fit
         CDER.gausscoords
         CDER.get_params
         CDER.plot
         CDER.predict
         CDER.runit
         CDER.score
         CDER.set_params



   

